@@ -55,7 +55,22 @@ else:
         """Adds MutableMapping mixin while pretending to be a builtin dict"""
 
 
-def item(value, _parent=None, _sort_keys=False):
+def item(
+    value: Any, _parent: Optional["Item"] = None, _sort_keys: bool = False
+) -> "Item":
+    """Create a TOML item from a Python object.
+
+    :Example:
+
+    >>> item(42)
+    42
+    >>> item([1, 2, 3])
+    [1, 2, 3]
+    >>> item({'a': 1, 'b': 2})
+    a = 1
+    b = 2
+    """
+
     from .container import Container
 
     if isinstance(value, Item):
@@ -77,7 +92,7 @@ def item(value, _parent=None, _sort_keys=False):
             val[k] = item(v, _parent=val, _sort_keys=_sort_keys)
 
         return val
-    elif isinstance(value, list):
+    elif isinstance(value, (list, tuple)):
         if value and all(isinstance(v, dict) for v in value):
             a = AoT([])
             table_constructor = Table
@@ -235,6 +250,8 @@ class KeyType(Enum):
 
 
 class Key(abc.ABC):
+    """Base class for a key"""
+
     sep: str
     _original: str
     _keys: List["SingleKey"]
@@ -250,16 +267,23 @@ class Key(abc.ABC):
         pass
 
     def is_dotted(self) -> bool:
+        """If the key is followed by other keys"""
         return self._dotted
 
     def __iter__(self) -> Iterator["SingleKey"]:
         return iter(self._keys)
 
     def concat(self, other: "Key") -> "DottedKey":
+        """Concatenate keys into a dotted key"""
         keys = self._keys + other._keys
         return DottedKey(keys, sep=self.sep)
 
+    def is_multi(self) -> bool:
+        """Check if the key contains multiple keys"""
+        return len(self._keys) > 1
+
     def as_string(self) -> str:
+        """The TOML representation"""
         return self._original
 
     def __str__(self) -> str:
@@ -303,9 +327,11 @@ class SingleKey(Key):
 
     @property
     def delimiter(self) -> str:
+        """The delimiter: double quote/single quote/none"""
         return self.t.value
 
     def is_bare(self) -> bool:
+        """Check if the key is bare"""
         return self.t == KeyType.Bare
 
     def __hash__(self) -> int:
@@ -329,9 +355,9 @@ class DottedKey(Key):
         if original is None:
             original = ".".join(k.as_string() for k in self._keys)
 
-        self.sep = "=" if sep is None else sep
+        self.sep = " = " if sep is None else sep
         self._original = original
-        self._dotted = True
+        self._dotted = False
         self.key = ".".join(k.key for k in self._keys)
 
     def __hash__(self) -> int:
@@ -351,6 +377,7 @@ class Item:
 
     @property
     def trivia(self) -> Trivia:
+        """The trivia element associated with this item"""
         return self._trivia
 
     @property
@@ -358,11 +385,13 @@ class Item:
         raise NotImplementedError()
 
     def as_string(self) -> str:
+        """The TOML representation"""
         raise NotImplementedError()
 
     # Helpers
 
     def comment(self, comment: str) -> "Item":
+        """Attach a comment to this item"""
         if not comment.strip().startswith("#"):
             comment = "# " + comment
 
@@ -372,6 +401,7 @@ class Item:
         return self
 
     def indent(self, indent: int) -> "Item":
+        """Indent this item with given number of spaces"""
         if self._trivia.indent.startswith("\n"):
             self._trivia.indent = "\n" + " " * indent
         else:
@@ -416,6 +446,7 @@ class Whitespace(Item):
 
     @property
     def value(self) -> str:
+        """The wrapped string of the whitespace"""
         return self._s
 
     @property
@@ -427,6 +458,7 @@ class Whitespace(Item):
         return 0
 
     def is_fixed(self) -> bool:
+        """If the whitespace is fixed, it can't be merged or discarded from the output."""
         return self._fixed
 
     def as_string(self) -> str:
@@ -480,6 +512,7 @@ class Integer(int, Item):
 
     @property
     def value(self) -> int:
+        """The wrapped integer value"""
         return self
 
     def as_string(self) -> str:
@@ -547,6 +580,7 @@ class Float(float, Item):
 
     @property
     def value(self) -> float:
+        """The wrapped float value"""
         return self
 
     def as_string(self) -> str:
@@ -607,6 +641,7 @@ class Bool(Item):
 
     @property
     def value(self) -> bool:
+        """The wrapped boolean value"""
         return self._value
 
     def as_string(self) -> str:
@@ -893,6 +928,20 @@ class Array(Item, _CustomList):
         return self
 
     def multiline(self, multiline: bool) -> "Array":
+        """Change the array to display in multiline or not.
+
+        :Example:
+
+        >>> a = item([1, 2, 3])
+        >>> print(a.as_string())
+        [1, 2, 3]
+        >>> print(a.multiline(True).as_string())
+        [
+            1,
+            2,
+            3,
+        ]
+        """
         self._multiline = multiline
 
         return self
@@ -927,9 +976,21 @@ class Array(Item, _CustomList):
         add_comma: bool = True,
         newline: bool = True,
     ) -> None:
-        """Add multiple items in a line.
+        """Add multiple items in a line to control the format precisely.
         When add_comma is True, only accept actual values and
         ", " will be added between values automatically.
+
+        :Example:
+
+        >>> a = array()
+        >>> a.add_line(1, 2, 3)
+        >>> a.add_line(4, 5, 6)
+        >>> a.add_line(indent="")
+        >>> print(a.as_string())
+        [
+            1, 2, 3,
+            4, 5, 6,
+        ]
         """
         values = self._value[:]
         new_values = []
@@ -974,6 +1035,7 @@ class Array(Item, _CustomList):
         self._reindex()
 
     def clear(self) -> None:
+        """Clear the array."""
         list.clear(self)
 
         self._value.clear()
@@ -1237,12 +1299,13 @@ class Table(AbstractTable):
         self._value.append(key, _item)
 
         if isinstance(key, Key):
-            key = key.key
+            key = next(iter(key)).key
+            _item = self._value[key]
 
         if key is not None:
             dict.__setitem__(self, key, _item)
 
-        m = re.match("(?s)^[^ ]*([ ]+).*$", self._trivia.indent)
+        m = re.match(r"(?s)^[^ ]*([ ]+).*$", self._trivia.indent)
         if not m:
             return self
 
@@ -1258,13 +1321,15 @@ class Table(AbstractTable):
         return self
 
     def raw_append(self, key: Union[Key, str], _item: Any) -> "Table":
+        """Similar to :meth:`append` but does not copy indentation."""
         if not isinstance(_item, Item):
             _item = item(_item)
 
         self._value.append(key, _item)
 
         if isinstance(key, Key):
-            key = key.key
+            key = next(iter(key)).key
+            _item = self._value[key]
 
         if key is not None:
             dict.__setitem__(self, key, _item)
@@ -1272,9 +1337,12 @@ class Table(AbstractTable):
         return self
 
     def is_aot_element(self) -> bool:
+        """True if the table is the direct child of an AOT element."""
         return self._is_aot_element
 
     def is_super_table(self) -> bool:
+        """A super table is the intermediate parent of a nested table as in [a.b.c].
+        If true, it won't appear in the TOML representation."""
         return self._is_super_table
 
     def as_string(self) -> str:
@@ -1283,6 +1351,7 @@ class Table(AbstractTable):
     # Helpers
 
     def indent(self, indent: int) -> "Table":
+        """Indent the table with given number of spaces."""
         super().indent(indent)
 
         m = re.match("(?s)^[^ ]*([ ]+).*$", self._trivia.indent)
